@@ -1,5 +1,4 @@
 import logging
-from functools import partial
 
 import numpy as np
 import torch
@@ -8,14 +7,15 @@ from torch import nn
 from deepqmc import Molecule
 from deepqmc.physics import pairwise_diffs, pairwise_distance
 from deepqmc.torchext import sloglindet, triu_flat
-from deepqmc.utils import NULL_DEBUG
 from deepqmc.wf import WaveFunction
 
 from .cusp import CuspCorrection, ElectronicAsymptotic
 from .distbasis import DistanceBasis
 from .gto import GTOBasis
 from .molorb import MolecularOrbital
-from .omni import OmniSchNet
+from .omni import OmniSchNet, SubnetFactory
+from .pyscfext import pyscf_from_mol
+from .schnet import ElectronicSchNet
 
 __version__ = '0.1.0'
 __all__ = ['PauliNet']
@@ -91,6 +91,7 @@ class PauliNet(WaveFunction):
         dist_feat_cutoff (float, a.u.): distance at which distance features
             go to zero
         backflow_channels (int): :math:`C`, number of backflow channels
+        omni_kwargs: arguments passed to :class:`~deepqmc.wf.paulinet.OmniSchNet`
 
     Attributes:
         jastrow: :class:`torch.nn.Module` representing the Jastrow factor
@@ -113,8 +114,8 @@ class PauliNet(WaveFunction):
         return_log=True,
         use_sloglindet='training',
         *,
-        cusp_correction=False,
-        cusp_electrons=False,
+        cusp_correction=True,
+        cusp_electrons=True,
         dist_feat_dim=32,
         dist_feat_cutoff=10.0,
         backflow_type='orbital',
@@ -123,6 +124,7 @@ class PauliNet(WaveFunction):
         rc_scaling=1.0,
         cusp_alpha=10.0,
         freeze_embed=False,
+        omni_kwargs=None,
     ):
         assert use_sloglindet in {'never', 'training', 'always'}
         assert return_log or use_sloglindet == 'never'
@@ -179,7 +181,9 @@ class PauliNet(WaveFunction):
         self.r_backflow = None
         if omni_factory:
             assert not backflow_factory and not jastrow_factory
-            self.omni = omni_factory(mol, dist_feat_dim, n_up, n_down, *backflow_spec)
+            self.omni = omni_factory(
+                mol, dist_feat_dim, n_up, n_down, *backflow_spec, **(omni_kwargs or {})
+            )
             self.backflow = self.omni.forward_backflow
             self.r_backflow = self.omni.forward_r_backflow
             self.jastrow = self.omni.forward_jastrow
@@ -215,6 +219,16 @@ class PauliNet(WaveFunction):
     def requires_grad_nets_(self, requires_grad):
         return self.requires_grad_classes_(nn.Linear, requires_grad)
 
+    @classmethod
+    def DEFAULTS(cls):
+        return {
+            (cls.from_hf, 'kwargs'): cls.from_pyscf,
+            (cls.from_pyscf, 'kwargs'): cls,
+            (cls, 'omni_kwargs'): OmniSchNet,
+            (OmniSchNet, 'schnet_kwargs'): ElectronicSchNet,
+            (OmniSchNet, 'subnet_kwargs'): SubnetFactory,
+        }
+
     @classmethod
     def from_pyscf(
         cls,
@@ -287,7 +301,7 @@ class PauliNet(WaveFunction):
             mf.mol.spin,
         )
         basis = GTOBasis.from_pyscf(mf.mol)
-        wf = cls(mol, basis, **kwargs)
+        wf = cls(mol, basis, **{'omni_factory': OmniSchNet, **kwargs})
         if init_weights:
             wf.mo.init_from_pyscf(mf, freeze_mos=freeze_mos)
             if confs is not None:
@@ -299,9 +313,7 @@ class PauliNet(WaveFunction):
         return wf
 
     @classmethod
-    def from_hf(
-        cls, mol, *, basis='6-311g', cas=None, pauli_kwargs=None, omni_kwargs=None
-    ):
+    def from_hf(cls, mol, *, basis='6-311g', cas=None, workdir=None, **kwargs):
         r"""Construct a :class:`PauliNet` instance by running a HF calculation.
 
         This is the top-level interface.
@@ -313,40 +325,22 @@ class PauliNet(WaveFunction):
             cas ((int, int)): tuple of the number of active orbitals and number of
                 active electrons for a complete active space multireference
                 HF calculation
-            pauli_kwargs: arguments passed to :func:`PauliNet.from_pyscf`
-            omni_kwargs: arguments passed to :class:`~deepqmc.wf.paulinet.OmniSchNet`
+            workdir (str): path where PySCF calculations are cached
+            kwargs: all other arguments are passed to :func:`PauliNet.from_pyscf`
         """
-        from pyscf import gto, mcscf, scf, lib
-
-        mol = gto.M(
-            atom=mol.as_pyscf(),
-            unit='bohr',
-            basis=basis,
-            charge=mol.charge,
-            spin=mol.spin,
-            cart=True,
-        )
-        log.info('Running HF...')
-        mf = scf.RHF(mol)
-        mf.kernel()
-        if cas:
-            log.info('Running MCSCF...')
-            mc = mcscf.CASSCF(mf, *cas)
-            mc.kernel()
-            lib.chkfile.dump(mc.chkfile, 'ci', mc.ci)
-            lib.chkfile.dump(mc.chkfile, 'nelecas', mc.nelecas)
-        wf = PauliNet.from_pyscf(
-            mc if cas else mf,
-            **{
-                'omni_factory': partial(OmniSchNet, **(omni_kwargs or {})),
-                'cusp_correction': True,
-                'cusp_electrons': True,
-                **(pauli_kwargs or {}),
-            },
-        )
+        mf, mc = pyscf_from_mol(mol, basis, cas, workdir)
+        assert bool(cas) == bool(mc)
+        wf = PauliNet.from_pyscf(mc or mf, **kwargs)
         wf.mf = mf
         return wf
 
+    def pop_chargse(self):
+        try:
+            mf = self.mf
+        except AttributeError:
+            return super().pop_charges()
+        return mf.pop(verbose=0)[1]
+
     def _backflow_op(self, xs, fs):
         if self.backflow_transform == 'mult':
             fs_mult, fs_add = fs, None
@@ -362,7 +356,7 @@ class PauliNet(WaveFunction):
             xs = xs + 0.1 * envel * torch.tanh(fs_add / 4)
         return xs
 
-    def forward(self, rs, debug=NULL_DEBUG):  # noqa: C901
+    def forward(self, rs):  # noqa: C901
         batch_dim, n_elec = rs.shape[:2]
         assert n_elec == self.confs.shape[1]
         n_atoms = len(self.mol)
@@ -379,17 +373,15 @@ class PauliNet(WaveFunction):
             edges_nuc = edges_nuc[n_atoms:].view(batch_dim, n_elec, n_atoms, -1)
             edges = self.dist_basis(dists_elec), edges_nuc
         if self.r_backflow:
-            rs_flowed = self.r_backflow(rs, *edges, debug=debug)
+            rs_flowed = self.r_backflow(rs, *edges)
             diffs_nuc = pairwise_diffs(
                 torch.cat([coords, rs_flowed.flatten(end_dim=1)]), coords
             )
-        with debug.cd('mos'):
-            xs = self.mo(diffs_nuc, edges_nuc, debug=debug)
+        xs = self.mo(diffs_nuc, edges_nuc)
         # get orbitals as [bs, 1, i, mu]
-        xs = debug['slaters'] = xs.view(batch_dim, 1, n_elec, -1)
+        xs = xs.view(batch_dim, 1, n_elec, -1)
         if self.backflow:
-            with debug.cd('backflow'):
-                fs = self.backflow(*edges, debug=debug)  # [bs, q, i, mu/nu]
+            fs = self.backflow(*edges)  # [bs, q, i, mu/nu]
             if self.backflow_type == 'orbital':
                 xs = self._backflow_op(xs, fs)
         # form dets as [bs, q, p, i, nu]
@@ -424,8 +416,8 @@ class PauliNet(WaveFunction):
                 # the exp-normalize trick, to avoid over/underflow of the exponential
                 xs = sign_up * sign_down * torch.exp(xs - xs_shift[:, None, None])
             else:
-                det_up = debug['det_up'] = eval_slater(det_up)
-                det_down = debug['det_down'] = eval_slater(det_down)
+                det_up = eval_slater(det_up)
+                det_down = eval_slater(det_down)
                 xs = det_up * det_down
             psi = self.conf_coeff(xs).squeeze(dim=-1).mean(dim=-1)
             if self.return_log:
@@ -446,9 +438,8 @@ class PauliNet(WaveFunction):
                 else psi * torch.exp(cusp_same + cusp_anti)
             )
         if self.jastrow:
-            with debug.cd('jastrow'):
-                J = self.jastrow(*edges, debug=debug)
-                psi = psi + J if self.return_log else psi * torch.exp(J)
+            J = self.jastrow(*edges)
+            psi = psi + J if self.return_log else psi * torch.exp(J)
         if self.omni:
             self.omni.forward_close()
         return (psi, sign) if self.return_log else psi
